# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/hooks.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/hooks.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63line/hooks.proto\x12\x05\x63line\"\x8e\x04\n\tHookInput\x12\x15\n\rcline_version\x18\x01 \x01(\t\x12\x11\n\thook_name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\t\x12\x17\n\x0fworkspace_roots\x18\x05 \x03(\t\x12\x0f\n\x07user_id\x18\x06 \x01(\t\x12-\n\x0cpre_tool_use\x18\n \x01(\x0b\x32\x15.cline.PreToolUseDataH\x00\x12/\n\rpost_tool_use\x18\x0b \x01(\x0b\x32\x16.cline.PostToolUseDataH\x00\x12\x39\n\x12user_prompt_submit\x18\x0c \x01(\x0b\x32\x1b.cline.UserPromptSubmitDataH\x00\x12*\n\ntask_start\x18\r \x01(\x0b\x32\x14.cline.TaskStartDataH\x00\x12,\n\x0btask_resume\x18\x0e \x01(\x0b\x32\x15.cline.TaskResumeDataH\x00\x12,\n\x0btask_cancel\x18\x0f \x01(\x0b\x32\x15.cline.TaskCancelDataH\x00\x12\x30\n\rtask_complete\x18\x10 \x01(\x0b\x32\x17.cline.TaskCompleteDataH\x00\x12,\n\x0bpre_compact\x18\x11 \x01(\x0b\x32\x15.cline.PreCompactDataH\x00\x42\x06\n\x04\x64\x61ta\"Q\n\nHookOutput\x12\x1c\n\x14\x63ontext_modification\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\x91\x01\n\x0ePreToolUseData\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12\x39\n\nparameters\x18\x02 \x03(\x0b\x32%.cline.PreToolUseData.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcf\x01\n\x0fPostToolUseData\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12:\n\nparameters\x18\x02 \x03(\x0b\x32&.cline.PostToolUseData.ParametersEntry\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x03\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x14UserPromptSubmitData\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x13\n\x0b\x61ttachments\x18\x02 \x03(\t\"\x83\x01\n\rTaskStartData\x12=\n\rtask_metadata\x18\x01 \x03(\x0b\x32&.cline.TaskStartData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfd\x01\n\x0eTaskResumeData\x12>\n\rtask_metadata\x18\x01 \x03(\x0b\x32\'.cline.TaskResumeData.TaskMetadataEntry\x12@\n\x0eprevious_state\x18\x02 \x03(\x0b\x32(.cline.TaskResumeData.PreviousStateEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12PreviousStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eTaskCancelData\x12>\n\rtask_metadata\x18\x01 \x03(\x0b\x32\'.cline.TaskCancelData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x10TaskCompleteData\x12@\n\rtask_metadata\x18\x01 \x03(\x0b\x32).cline.TaskCompleteData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x0ePreCompactData\x12\x14\n\x0c\x63ontext_size\x18\x01 \x01(\x03\x12\x1b\n\x13messages_to_compact\x18\x02 \x01(\x05\x12\x1b\n\x13\x63ompaction_strategy\x18\x03 \x01(\tB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.hooks_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._loaded_options = None
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._loaded_options = None
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._loaded_options = None
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_options = b'8\001'
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_HOOKINPUT']._serialized_start=29
  _globals['_HOOKINPUT']._serialized_end=555
  _globals['_HOOKOUTPUT']._serialized_start=557
  _globals['_HOOKOUTPUT']._serialized_end=638
  _globals['_PRETOOLUSEDATA']._serialized_start=641
  _globals['_PRETOOLUSEDATA']._serialized_end=786
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_start=737
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_end=786
  _globals['_POSTTOOLUSEDATA']._serialized_start=789
  _globals['_POSTTOOLUSEDATA']._serialized_end=996
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_start=737
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_end=786
  _globals['_USERPROMPTSUBMITDATA']._serialized_start=998
  _globals['_USERPROMPTSUBMITDATA']._serialized_end=1057
  _globals['_TASKSTARTDATA']._serialized_start=1060
  _globals['_TASKSTARTDATA']._serialized_end=1191
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKRESUMEDATA']._serialized_start=1194
  _globals['_TASKRESUMEDATA']._serialized_end=1447
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_start=1395
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_end=1447
  _globals['_TASKCANCELDATA']._serialized_start=1450
  _globals['_TASKCANCELDATA']._serialized_end=1583
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKCOMPLETEDATA']._serialized_start=1586
  _globals['_TASKCOMPLETEDATA']._serialized_end=1723
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_PRECOMPACTDATA']._serialized_start=1725
  _globals['_PRECOMPACTDATA']._serialized_end=1821
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import browser_pb2 as cline_dot_browser__pb2
from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import models_pb2 as cline_dot_models__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63line/state.proto\x12\x05\x63line\x1a\x13\x63line/browser.proto\x1a\x12\x63line/common.proto\x1a\x12\x63line/models.proto\"\xa7\x03\n\x13\x41utoApprovalActions\x12\x17\n\nread_files\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\"\n\x15read_files_externally\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x17\n\nedit_files\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\"\n\x15\x65\x64it_files_externally\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\"\n\x15\x65xecute_safe_commands\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12!\n\x14\x65xecute_all_commands\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x18\n\x0buse_browser\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x14\n\x07use_mcp\x18\x08 \x01(\x08H\x07\x88\x01\x01\x42\r\n\x0b_read_filesB\x18\n\x16_read_files_externallyB\r\n\x0b_edit_filesB\x18\n\x16_edit_files_externallyB\x18\n\x16_execute_safe_commandsB\x17\n\x15_execute_all_commandsB\x0e\n\x0c_use_browserB\n\n\x08_use_mcp\"\x90\x01\n\x14\x41utoApprovalSettings\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12+\n\x07\x61\x63tions\x18\x02 \x01(\x0b\x32\x1a.cline.AutoApprovalActions\x12!\n\x14\x65nable_notifications\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x17\n\x15_enable_notifications\"\xfd\x0e\n\x07Secrets\x12\x14\n\x07\x61pi_key\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x13open_router_api_key\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x1b\n\x0e\x61ws_access_key\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x0e\x61ws_secret_key\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x1e\n\x11\x61ws_session_token\x18\x07 \x01(\tH\x04\x88\x01\x01\x12 \n\x13\x61ws_bedrock_api_key\x18\x08 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0fopen_ai_api_key\x18\t \x01(\tH\x06\x88\x01\x01\x12\x1b\n\x0egemini_api_key\x18\n \x01(\tH\x07\x88\x01\x01\x12#\n\x16open_ai_native_api_key\x18\x0b \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0eollama_api_key\x18\x0c \x01(\tH\t\x88\x01\x01\x12\x1e\n\x11\x64\x65\x65p_seek_api_key\x18\r \x01(\tH\n\x88\x01\x01\x12\x1d\n\x10requesty_api_key\x18\x0e \x01(\tH\x0b\x88\x01\x01\x12\x1d\n\x10together_api_key\x18\x0f \x01(\tH\x0c\x88\x01\x01\x12\x1e\n\x11\x66ireworks_api_key\x18\x10 \x01(\tH\r\x88\x01\x01\x12\x19\n\x0cqwen_api_key\x18\x11 \x01(\tH\x0e\x88\x01\x01\x12\x1b\n\x0e\x64oubao_api_key\x18\x12 \x01(\tH\x0f\x88\x01\x01\x12\x1c\n\x0fmistral_api_key\x18\x13 \x01(\tH\x10\x88\x01\x01\x12\x1d\n\x10lite_llm_api_key\x18\x14 \x01(\tH\x11\x88\x01\x01\x12\x17\n\nauth_nonce\x18\x15 \x01(\tH\x12\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_key\x18\x16 \x01(\tH\x13\x88\x01\x01\x12\x18\n\x0bxai_api_key\x18\x17 \x01(\tH\x14\x88\x01\x01\x12\x1d\n\x10moonshot_api_key\x18\x18 \x01(\tH\x15\x88\x01\x01\x12\x18\n\x0bzai_api_key\x18\x19 \x01(\tH\x16\x88\x01\x01\x12!\n\x14hugging_face_api_key\x18\x1a \x01(\tH\x17\x88\x01\x01\x12\x1b\n\x0enebius_api_key\x18\x1b \x01(\tH\x18\x88\x01\x01\x12\x1e\n\x11sambanova_api_key\x18\x1c \x01(\tH\x19\x88\x01\x01\x12\x1d\n\x10\x63\x65rebras_api_key\x18\x1d \x01(\tH\x1a\x88\x01\x01\x12\"\n\x15sap_ai_core_client_id\x18\x1e \x01(\tH\x1b\x88\x01\x01\x12&\n\x19sap_ai_core_client_secret\x18\x1f \x01(\tH\x1c\x88\x01\x01\x12\x19\n\x0cgroq_api_key\x18  \x01(\tH\x1d\x88\x01\x01\x12&\n\x19huawei_cloud_maas_api_key\x18! \x01(\tH\x1e\x88\x01\x01\x12\x1c\n\x0f\x62\x61seten_api_key\x18\" \x01(\tH\x1f\x88\x01\x01\x12&\n\x19vercel_ai_gateway_api_key\x18# \x01(\tH \x88\x01\x01\x12\x19\n\x0c\x64ify_api_key\x18$ \x01(\tH!\x88\x01\x01\x12\x18\n\x0boca_api_key\x18% \x01(\tH\"\x88\x01\x01\x12\x1e\n\x11oca_refresh_token\x18& \x01(\tH#\x88\x01\x01\x12\x1a\n\rhicap_api_key\x18\' \x01(\tH$\x88\x01\x01\x42\n\n\x08_api_keyB\x16\n\x14_open_router_api_keyB\x11\n\x0f_aws_access_keyB\x11\n\x0f_aws_secret_keyB\x14\n\x12_aws_session_tokenB\x16\n\x14_aws_bedrock_api_keyB\x12\n\x10_open_ai_api_keyB\x11\n\x0f_gemini_api_keyB\x19\n\x17_open_ai_native_api_keyB\x11\n\x0f_ollama_api_keyB\x14\n\x12_deep_seek_api_keyB\x13\n\x11_requesty_api_keyB\x13\n\x11_together_api_keyB\x14\n\x12_fireworks_api_keyB\x0f\n\r_qwen_api_keyB\x11\n\x0f_doubao_api_keyB\x12\n\x10_mistral_api_keyB\x13\n\x11_lite_llm_api_keyB\r\n\x0b_auth_nonceB\x12\n\x10_asksage_api_keyB\x0e\n\x0c_xai_api_keyB\x13\n\x11_moonshot_api_keyB\x0e\n\x0c_zai_api_keyB\x17\n\x15_hugging_face_api_keyB\x11\n\x0f_nebius_api_keyB\x14\n\x12_sambanova_api_keyB\x13\n\x11_cerebras_api_keyB\x18\n\x16_sap_ai_core_client_idB\x1c\n\x1a_sap_ai_core_client_secretB\x0f\n\r_groq_api_keyB\x1c\n\x1a_huawei_cloud_maas_api_keyB\x12\n\x10_baseten_api_keyB\x1c\n\x1a_vercel_ai_gateway_api_keyB\x0f\n\r_dify_api_keyB\x0e\n\x0c_oca_api_keyB\x14\n\x12_oca_refresh_tokenB\x10\n\x0e_hicap_api_key\"\xc4M\n\x08Settings\x12\x17\n\naws_region\x18\x01 \x01(\tH\x00\x88\x01\x01\x12+\n\x1e\x61ws_use_cross_region_inference\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12)\n\x1c\x61ws_bedrock_use_prompt_cache\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12!\n\x14\x61ws_bedrock_endpoint\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x61ws_profile\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1f\n\x12\x61ws_authentication\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1c\n\x0f\x61ws_use_profile\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x1e\n\x11vertex_project_id\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1a\n\rvertex_region\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1e\n\x11requesty_base_url\x18\n \x01(\tH\t\x88\x01\x01\x12\x1d\n\x10open_ai_base_url\x18\x0b \x01(\tH\n\x88\x01\x01\x12\x1c\n\x0follama_base_url\x18\r \x01(\tH\x0b\x88\x01\x01\x12\'\n\x1aollama_api_options_ctx_num\x18\x0e \x01(\tH\x0c\x88\x01\x01\x12\x1f\n\x12lm_studio_base_url\x18\x0f \x01(\tH\r\x88\x01\x01\x12!\n\x14lm_studio_max_tokens\x18\x10 \x01(\tH\x0e\x88\x01\x01\x12\x1f\n\x12\x61nthropic_base_url\x18\x11 \x01(\tH\x0f\x88\x01\x01\x12\x1c\n\x0fgemini_base_url\x18\x12 \x01(\tH\x10\x88\x01\x01\x12\x1e\n\x11\x61zure_api_version\x18\x13 \x01(\tH\x11\x88\x01\x01\x12)\n\x1copen_router_provider_sorting\x18\x14 \x01(\tH\x12\x88\x01\x01\x12@\n\x16\x61uto_approval_settings\x18\x15 \x01(\x0b\x32\x1b.cline.AutoApprovalSettingsH\x13\x88\x01\x01\x12\x35\n\x10\x62rowser_settings\x18\x18 \x01(\x0b\x32\x16.cline.BrowserSettingsH\x14\x88\x01\x01\x12\x1e\n\x11lite_llm_base_url\x18\x19 \x01(\tH\x15\x88\x01\x01\x12&\n\x19lite_llm_use_prompt_cache\x18\x1a \x01(\x08H\x16\x88\x01\x01\x12\x32\n%fireworks_model_max_completion_tokens\x18\x1b \x01(\x05H\x17\x88\x01\x01\x12\'\n\x1a\x66ireworks_model_max_tokens\x18\x1c \x01(\x05H\x18\x88\x01\x01\x12\x1a\n\rqwen_api_line\x18\x1d \x01(\tH\x19\x88\x01\x01\x12\x1e\n\x11moonshot_api_line\x18\x1e \x01(\tH\x1a\x88\x01\x01\x12\x19\n\x0czai_api_line\x18\x1f \x01(\tH\x1b\x88\x01\x01\x12\x1e\n\x11telemetry_setting\x18  \x01(\tH\x1c\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_url\x18! \x01(\tH\x1d\x88\x01\x01\x12-\n plan_act_separate_models_setting\x18\" \x01(\x08H\x1e\x88\x01\x01\x12\'\n\x1a\x65nable_checkpoints_setting\x18# \x01(\x08H\x1f\x88\x01\x01\x12\x1f\n\x12request_timeout_ms\x18$ \x01(\x05H \x88\x01\x01\x12&\n\x19shell_integration_timeout\x18% \x01(\x05H!\x88\x01\x01\x12%\n\x18\x64\x65\x66\x61ult_terminal_profile\x18& \x01(\tH\"\x88\x01\x01\x12\'\n\x1aterminal_output_line_limit\x18\' \x01(\x05H#\x88\x01\x01\x12\"\n\x15sap_ai_core_token_url\x18( \x01(\tH$\x88\x01\x01\x12!\n\x14sap_ai_core_base_url\x18) \x01(\tH%\x88\x01\x01\x12\"\n\x15sap_ai_resource_group\x18* \x01(\tH&\x88\x01\x01\x12/\n\"sap_ai_core_use_orchestration_mode\x18+ \x01(\x08H\'\x88\x01\x01\x12\x1d\n\x10\x63laude_code_path\x18, \x01(\tH(\x88\x01\x01\x12!\n\x14qwen_code_oauth_path\x18- \x01(\tH)\x88\x01\x01\x12%\n\x18strict_plan_mode_enabled\x18. \x01(\x08H*\x88\x01\x01\x12\x1e\n\x11yolo_mode_toggled\x18/ \x01(\x08H+\x88\x01\x01\x12\x1e\n\x11use_auto_condense\x18\x30 \x01(\x08H,\x88\x01\x01\x12\x1f\n\x12preferred_language\x18\x31 \x01(\tH-\x88\x01\x01\x12\x42\n\x17openai_reasoning_effort\x18\x32 \x01(\x0e\x32\x1c.cline.OpenaiReasoningEffortH.\x88\x01\x01\x12%\n\x04mode\x18\x33 \x01(\x0e\x32\x12.cline.PlanActModeH/\x88\x01\x01\x12\x39\n\x12\x64ictation_settings\x18\x34 \x01(\x0b\x32\x18.cline.DictationSettingsH0\x88\x01\x01\x12<\n\x14\x66ocus_chain_settings\x18\x35 \x01(\x0b\x32\x19.cline.FocusChainSettingsH1\x88\x01\x01\x12\x1a\n\rcustom_prompt\x18\x36 \x01(\tH2\x88\x01\x01\x12\x1a\n\rdify_base_url\x18\x37 \x01(\tH3\x88\x01\x01\x12$\n\x17\x61uto_condense_threshold\x18\x38 \x01(\x01H4\x88\x01\x01\x12\x19\n\x0coca_base_url\x18\x39 \x01(\tH5\x88\x01\x01\x12\x37\n\x16plan_mode_api_provider\x18: \x01(\x0e\x32\x12.cline.ApiProviderH6\x88\x01\x01\x12#\n\x16plan_mode_api_model_id\x18; \x01(\tH7\x88\x01\x01\x12-\n plan_mode_thinking_budget_tokens\x18< \x01(\x03H8\x88\x01\x01\x12\'\n\x1aplan_mode_reasoning_effort\x18= \x01(\tH9\x88\x01\x01\x12R\n#plan_mode_vs_code_lm_model_selector\x18> \x01(\x0b\x32 .cline.LanguageModelChatSelectorH:\x88\x01\x01\x12\x32\n%plan_mode_aws_bedrock_custom_selected\x18? \x01(\x08H;\x88\x01\x01\x12\x37\n*plan_mode_aws_bedrock_custom_model_base_id\x18@ \x01(\tH<\x88\x01\x01\x12+\n\x1eplan_mode_open_router_model_id\x18\x41 \x01(\tH=\x88\x01\x01\x12I\n plan_mode_open_router_model_info\x18\x42 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH>\x88\x01\x01\x12\'\n\x1aplan_mode_open_ai_model_id\x18\x43 \x01(\tH?\x88\x01\x01\x12K\n\x1cplan_mode_open_ai_model_info\x18\x44 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH@\x88\x01\x01\x12&\n\x19plan_mode_ollama_model_id\x18\x45 \x01(\tHA\x88\x01\x01\x12)\n\x1cplan_mode_lm_studio_model_id\x18\x46 \x01(\tHB\x88\x01\x01\x12(\n\x1bplan_mode_lite_llm_model_id\x18G \x01(\tHC\x88\x01\x01\x12\x43\n\x1dplan_mode_lite_llm_model_info\x18H \x01(\x0b\x32\x17.cline.LiteLLMModelInfoHD\x88\x01\x01\x12(\n\x1bplan_mode_requesty_model_id\x18I \x01(\tHE\x88\x01\x01\x12\x46\n\x1dplan_mode_requesty_model_info\x18J \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHF\x88\x01\x01\x12(\n\x1bplan_mode_together_model_id\x18K \x01(\tHG\x88\x01\x01\x12)\n\x1cplan_mode_fireworks_model_id\x18L \x01(\tHH\x88\x01\x01\x12+\n\x1eplan_mode_sap_ai_core_model_id\x18M \x01(\tHI\x88\x01\x01\x12\x30\n#plan_mode_sap_ai_core_deployment_id\x18N \x01(\tHJ\x88\x01\x01\x12$\n\x17plan_mode_groq_model_id\x18O \x01(\tHK\x88\x01\x01\x12\x42\n\x19plan_mode_groq_model_info\x18P \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHL\x88\x01\x01\x12\'\n\x1aplan_mode_baseten_model_id\x18Q \x01(\tHM\x88\x01\x01\x12\x45\n\x1cplan_mode_baseten_model_info\x18R \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHN\x88\x01\x01\x12,\n\x1fplan_mode_hugging_face_model_id\x18S \x01(\tHO\x88\x01\x01\x12J\n!plan_mode_hugging_face_model_info\x18T \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHP\x88\x01\x01\x12\x31\n$plan_mode_huawei_cloud_maas_model_id\x18U \x01(\tHQ\x88\x01\x01\x12O\n&plan_mode_huawei_cloud_maas_model_info\x18V \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHR\x88\x01\x01\x12#\n\x16plan_mode_oca_model_id\x18W \x01(\tHS\x88\x01\x01\x12:\n\x18plan_mode_oca_model_info\x18X \x01(\x0b\x32\x13.cline.OcaModelInfoHT\x88\x01\x01\x12\x36\n\x15\x61\x63t_mode_api_provider\x18Y \x01(\x0e\x32\x12.cline.ApiProviderHU\x88\x01\x01\x12\"\n\x15\x61\x63t_mode_api_model_id\x18Z \x01(\tHV\x88\x01\x01\x12,\n\x1f\x61\x63t_mode_thinking_budget_tokens\x18[ \x01(\x03HW\x88\x01\x01\x12&\n\x19\x61\x63t_mode_reasoning_effort\x18\\ \x01(\tHX\x88\x01\x01\x12Q\n\"act_mode_vs_code_lm_model_selector\x18] \x01(\x0b\x32 .cline.LanguageModelChatSelectorHY\x88\x01\x01\x12\x31\n$act_mode_aws_bedrock_custom_selected\x18^ \x01(\x08HZ\x88\x01\x01\x12\x36\n)act_mode_aws_bedrock_custom_model_base_id\x18_ \x01(\tH[\x88\x01\x01\x12*\n\x1d\x61\x63t_mode_open_router_model_id\x18` \x01(\tH\\\x88\x01\x01\x12H\n\x1f\x61\x63t_mode_open_router_model_info\x18\x61 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH]\x88\x01\x01\x12&\n\x19\x61\x63t_mode_open_ai_model_id\x18\x62 \x01(\tH^\x88\x01\x01\x12J\n\x1b\x61\x63t_mode_open_ai_model_info\x18\x63 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH_\x88\x01\x01\x12%\n\x18\x61\x63t_mode_ollama_model_id\x18\x64 \x01(\tH`\x88\x01\x01\x12(\n\x1b\x61\x63t_mode_lm_studio_model_id\x18\x65 \x01(\tHa\x88\x01\x01\x12\'\n\x1a\x61\x63t_mode_lite_llm_model_id\x18\x66 \x01(\tHb\x88\x01\x01\x12\x42\n\x1c\x61\x63t_mode_lite_llm_model_info\x18g \x01(\x0b\x32\x17.cline.LiteLLMModelInfoHc\x88\x01\x01\x12\'\n\x1a\x61\x63t_mode_requesty_model_id\x18h \x01(\tHd\x88\x01\x01\x12\x45\n\x1c\x61\x63t_mode_requesty_model_info\x18i \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHe\x88\x01\x01\x12\'\n\x1a\x61\x63t_mode_together_model_id\x18j \x01(\tHf\x88\x01\x01\x12(\n\x1b\x61\x63t_mode_fireworks_model_id\x18k \x01(\tHg\x88\x01\x01\x12*\n\x1d\x61\x63t_mode_sap_ai_core_model_id\x18l \x01(\tHh\x88\x01\x01\x12/\n\"act_mode_sap_ai_core_deployment_id\x18m \x01(\tHi\x88\x01\x01\x12#\n\x16\x61\x63t_mode_groq_model_id\x18n \x01(\tHj\x88\x01\x01\x12\x41\n\x18\x61\x63t_mode_groq_model_info\x18o \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHk\x88\x01\x01\x12&\n\x19\x61\x63t_mode_baseten_model_id\x18p \x01(\tHl\x88\x01\x01\x12\x44\n\x1b\x61\x63t_mode_baseten_model_info\x18q \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHm\x88\x01\x01\x12+\n\x1e\x61\x63t_mode_hugging_face_model_id\x18r \x01(\tHn\x88\x01\x01\x12I\n act_mode_hugging_face_model_info\x18s \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHo\x88\x01\x01\x12\x30\n#act_mode_huawei_cloud_maas_model_id\x18t \x01(\tHp\x88\x01\x01\x12N\n%act_mode_huawei_cloud_maas_model_info\x18u \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHq\x88\x01\x01\x12\x31\n$plan_mode_vercel_ai_gateway_model_id\x18v \x01(\tHr\x88\x01\x01\x12O\n&plan_mode_vercel_ai_gateway_model_info\x18w \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHs\x88\x01\x01\x12\x30\n#act_mode_vercel_ai_gateway_model_id\x18x \x01(\tHt\x88\x01\x01\x12N\n%act_mode_vercel_ai_gateway_model_info\x18y \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHu\x88\x01\x01\x12\"\n\x15\x61\x63t_mode_oca_model_id\x18z \x01(\tHv\x88\x01\x01\x12\x39\n\x17\x61\x63t_mode_oca_model_info\x18{ \x01(\x0b\x32\x13.cline.OcaModelInfoHw\x88\x01\x01\x12%\n\x18max_consecutive_mistakes\x18| \x01(\x05Hx\x88\x01\x01\x12\x1e\n\x11subagents_enabled\x18} \x01(\x08Hy\x88\x01\x01\x12\x30\n#subagent_terminal_output_line_limit\x18~ \x01(\x05Hz\x88\x01\x01\x12\x1d\n\x10\x61ihubmix_api_key\x18\x7f \x01(\tH{\x88\x01\x01\x12\x1f\n\x11\x61ihubmix_base_url\x18\x80\x01 \x01(\tH|\x88\x01\x01\x12\x1f\n\x11\x61ihubmix_app_code\x18\x81\x01 \x01(\tH}\x88\x01\x01\x12)\n\x1bplan_mode_aihubmix_model_id\x18\x82\x01 \x01(\tH~\x88\x01\x01\x12M\n\x1dplan_mode_aihubmix_model_info\x18\x83\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH\x7f\x88\x01\x01\x12)\n\x1a\x61\x63t_mode_aihubmix_model_id\x18\x84\x01 \x01(\tH\x80\x01\x88\x01\x01\x12M\n\x1c\x61\x63t_mode_aihubmix_model_info\x18\x85\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH\x81\x01\x88\x01\x01\x42\r\n\x0b_aws_regionB!\n\x1f_aws_use_cross_region_inferenceB\x1f\n\x1d_aws_bedrock_use_prompt_cacheB\x17\n\x15_aws_bedrock_endpointB\x0e\n\x0c_aws_profileB\x15\n\x13_aws_authenticationB\x12\n\x10_aws_use_profileB\x14\n\x12_vertex_project_idB\x10\n\x0e_vertex_regionB\x14\n\x12_requesty_base_urlB\x13\n\x11_open_ai_base_urlB\x12\n\x10_ollama_base_urlB\x1d\n\x1b_ollama_api_options_ctx_numB\x15\n\x13_lm_studio_base_urlB\x17\n\x15_lm_studio_max_tokensB\x15\n\x13_anthropic_base_urlB\x12\n\x10_gemini_base_urlB\x14\n\x12_azure_api_versionB\x1f\n\x1d_open_router_provider_sortingB\x19\n\x17_auto_approval_settingsB\x13\n\x11_browser_settingsB\x14\n\x12_lite_llm_base_urlB\x1c\n\x1a_lite_llm_use_prompt_cacheB(\n&_fireworks_model_max_completion_tokensB\x1d\n\x1b_fireworks_model_max_tokensB\x10\n\x0e_qwen_api_lineB\x14\n\x12_moonshot_api_lineB\x0f\n\r_zai_api_lineB\x14\n\x12_telemetry_settingB\x12\n\x10_asksage_api_urlB#\n!_plan_act_separate_models_settingB\x1d\n\x1b_enable_checkpoints_settingB\x15\n\x13_request_timeout_msB\x1c\n\x1a_shell_integration_timeoutB\x1b\n\x19_default_terminal_profileB\x1d\n\x1b_terminal_output_line_limitB\x18\n\x16_sap_ai_core_token_urlB\x17\n\x15_sap_ai_core_base_urlB\x18\n\x16_sap_ai_resource_groupB%\n#_sap_ai_core_use_orchestration_modeB\x13\n\x11_claude_code_pathB\x17\n\x15_qwen_code_oauth_pathB\x1b\n\x19_strict_plan_mode_enabledB\x14\n\x12_yolo_mode_toggledB\x14\n\x12_use_auto_condenseB\x15\n\x13_preferred_languageB\x1a\n\x18_openai_reasoning_effortB\x07\n\x05_modeB\x15\n\x13_dictation_settingsB\x17\n\x15_focus_chain_settingsB\x10\n\x0e_custom_promptB\x10\n\x0e_dify_base_urlB\x1a\n\x18_auto_condense_thresholdB\x0f\n\r_oca_base_urlB\x19\n\x17_plan_mode_api_providerB\x19\n\x17_plan_mode_api_model_idB#\n!_plan_mode_thinking_budget_tokensB\x1d\n\x1b_plan_mode_reasoning_effortB&\n$_plan_mode_vs_code_lm_model_selectorB(\n&_plan_mode_aws_bedrock_custom_selectedB-\n+_plan_mode_aws_bedrock_custom_model_base_idB!\n\x1f_plan_mode_open_router_model_idB#\n!_plan_mode_open_router_model_infoB\x1d\n\x1b_plan_mode_open_ai_model_idB\x1f\n\x1d_plan_mode_open_ai_model_infoB\x1c\n\x1a_plan_mode_ollama_model_idB\x1f\n\x1d_plan_mode_lm_studio_model_idB\x1e\n\x1c_plan_mode_lite_llm_model_idB \n\x1e_plan_mode_lite_llm_model_infoB\x1e\n\x1c_plan_mode_requesty_model_idB \n\x1e_plan_mode_requesty_model_infoB\x1e\n\x1c_plan_mode_together_model_idB\x1f\n\x1d_plan_mode_fireworks_model_idB!\n\x1f_plan_mode_sap_ai_core_model_idB&\n$_plan_mode_sap_ai_core_deployment_idB\x1a\n\x18_plan_mode_groq_model_idB\x1c\n\x1a_plan_mode_groq_model_infoB\x1d\n\x1b_plan_mode_baseten_model_idB\x1f\n\x1d_plan_mode_baseten_model_infoB\"\n _plan_mode_hugging_face_model_idB$\n\"_plan_mode_hugging_face_model_infoB\'\n%_plan_mode_huawei_cloud_maas_model_idB)\n\'_plan_mode_huawei_cloud_maas_model_infoB\x19\n\x17_plan_mode_oca_model_idB\x1b\n\x19_plan_mode_oca_model_infoB\x18\n\x16_act_mode_api_providerB\x18\n\x16_act_mode_api_model_idB\"\n _act_mode_thinking_budget_tokensB\x1c\n\x1a_act_mode_reasoning_effortB%\n#_act_mode_vs_code_lm_model_selectorB\'\n%_act_mode_aws_bedrock_custom_selectedB,\n*_act_mode_aws_bedrock_custom_model_base_idB \n\x1e_act_mode_open_router_model_idB\"\n _act_mode_open_router_model_infoB\x1c\n\x1a_act_mode_open_ai_model_idB\x1e\n\x1c_act_mode_open_ai_model_infoB\x1b\n\x19_act_mode_ollama_model_idB\x1e\n\x1c_act_mode_lm_studio_model_idB\x1d\n\x1b_act_mode_lite_llm_model_idB\x1f\n\x1d_act_mode_lite_llm_model_infoB\x1d\n\x1b_act_mode_requesty_model_idB\x1f\n\x1d_act_mode_requesty_model_infoB\x1d\n\x1b_act_mode_together_model_idB\x1e\n\x1c_act_mode_fireworks_model_idB \n\x1e_act_mode_sap_ai_core_model_idB%\n#_act_mode_sap_ai_core_deployment_idB\x19\n\x17_act_mode_groq_model_idB\x1b\n\x19_act_mode_groq_model_infoB\x1c\n\x1a_act_mode_baseten_model_idB\x1e\n\x1c_act_mode_baseten_model_infoB!\n\x1f_act_mode_hugging_face_model_idB#\n!_act_mode_hugging_face_model_infoB&\n$_act_mode_huawei_cloud_maas_model_idB(\n&_act_mode_huawei_cloud_maas_model_infoB\'\n%_plan_mode_vercel_ai_gateway_model_idB)\n\'_plan_mode_vercel_ai_gateway_model_infoB&\n$_act_mode_vercel_ai_gateway_model_idB(\n&_act_mode_vercel_ai_gateway_model_infoB\x18\n\x16_act_mode_oca_model_idB\x1a\n\x18_act_mode_oca_model_infoB\x1b\n\x19_max_consecutive_mistakesB\x14\n\x12_subagents_enabledB&\n$_subagent_terminal_output_line_limitB\x13\n\x11_aihubmix_api_keyB\x14\n\x12_aihubmix_base_urlB\x14\n\x12_aihubmix_app_codeB\x1e\n\x1c_plan_mode_aihubmix_model_idB \n\x1e_plan_mode_aihubmix_model_infoB\x1d\n\x1b_act_mode_aihubmix_model_idB\x1f\n\x1d_act_mode_aihubmix_model_info\"c\n\x11\x44ictationSettings\x12\x17\n\x0f\x66\x65\x61ture_enabled\x18\x01 \x01(\x08\x12\x19\n\x11\x64ictation_enabled\x18\x02 \x01(\x08\x12\x1a\n\x12\x64ictation_language\x18\x03 \x01(\t\"\x1b\n\x05State\x12\x12\n\nstate_json\x18\x01 \x01(\t\"<\n\x10TerminalProfiles\x12(\n\x08profiles\x18\x01 \x03(\x0b\x32\x16.cline.TerminalProfile\"q\n\x0fTerminalProfile\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\x04path\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_pathB\x0e\n\x0c_description\"o\n\x1dTerminalProfileUpdateResponse\x12\x14\n\x0c\x63losed_count\x18\x01 \x01(\x05\x12\x1c\n\x14\x62usy_terminals_count\x18\x02 \x01(\x05\x12\x1a\n\x12has_busy_terminals\x18\x03 \x01(\x08\"\x9f\x01\n\x18TogglePlanActModeRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12 \n\x04mode\x18\x02 \x01(\x0e\x32\x12.cline.PlanActMode\x12-\n\x0c\x63hat_content\x18\x03 \x01(\x0b\x32\x12.cline.ChatContentH\x00\x88\x01\x01\x42\x0f\n\r_chat_content\"N\n\x0b\x43hatContent\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06images\x18\x02 \x03(\t\x12\r\n\x05\x66iles\x18\x03 \x03(\tB\n\n\x08_message\"V\n\x11ResetStateRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x13\n\x06global\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_global\"\x9c\x01\n\x1b\x41utoApprovalSettingsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12+\n\x07\x61\x63tions\x18\x03 \x01(\x0b\x32\x1a.cline.AutoApprovalActions\x12\x1c\n\x14\x65nable_notifications\x18\x04 \x01(\x08\"j\n\x17TelemetrySettingRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12,\n\x07setting\x18\x02 \x01(\x0e\x32\x1b.cline.TelemetrySettingEnum\"\xe4\x02\n\x15\x42rowserSettingsUpdate\x12&\n\x08viewport\x18\x01 \x01(\x0b\x32\x0f.cline.ViewportH\x00\x88\x01\x01\x12 \n\x13remote_browser_host\x18\x02 \x01(\tH\x01\x88\x01\x01\x12#\n\x16remote_browser_enabled\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12#\n\x16\x63hrome_executable_path\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1d\n\x10\x64isable_tool_use\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x18\n\x0b\x63ustom_args\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x0b\n\t_viewportB\x16\n\x14_remote_browser_hostB\x19\n\x17_remote_browser_enabledB\x19\n\x17_chrome_executable_pathB\x13\n\x11_disable_tool_useB\x0e\n\x0c_custom_args\"\xce\x01\n\x18UpdateSettingsRequestCli\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12&\n\x08settings\x18\x02 \x01(\x0b\x32\x0f.cline.SettingsH\x00\x88\x01\x01\x12$\n\x07secrets\x18\x03 \x01(\x0b\x32\x0e.cline.SecretsH\x01\x88\x01\x01\x12\x18\n\x0b\x65nvironment\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_settingsB\n\n\x08_secretsB\x0e\n\x0c_environment\"\x95\x01\n\x19UpdateTaskSettingsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12&\n\x08settings\x18\x02 \x01(\x0b\x32\x0f.cline.SettingsH\x00\x88\x01\x01\x12\x14\n\x07task_id\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_settingsB\n\n\x08_task_id\"\x99\x10\n\x15UpdateSettingsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12=\n\x11\x61pi_configuration\x18\x02 \x01(\x0b\x32\x1d.cline.ModelsApiConfigurationH\x00\x88\x01\x01\x12\x1e\n\x11telemetry_setting\x18\x03 \x01(\tH\x01\x88\x01\x01\x12-\n plan_act_separate_models_setting\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\'\n\x1a\x65nable_checkpoints_setting\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12$\n\x17mcp_marketplace_enabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x12&\n\x19shell_integration_timeout\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12#\n\x16terminal_reuse_enabled\x18\t \x01(\x08H\x06\x88\x01\x01\x12$\n\x17mcp_responses_collapsed\x18\n \x01(\x08H\x07\x88\x01\x01\x12\x34\n\x10mcp_display_mode\x18\x0b \x01(\x0e\x32\x15.cline.McpDisplayModeH\x08\x88\x01\x01\x12\'\n\x1aterminal_output_line_limit\x18\x0c \x01(\x05H\t\x88\x01\x01\x12%\n\x04mode\x18\r \x01(\x0e\x32\x12.cline.PlanActModeH\n\x88\x01\x01\x12\x1f\n\x12preferred_language\x18\x0e \x01(\tH\x0b\x88\x01\x01\x12\x42\n\x17openai_reasoning_effort\x18\x0f \x01(\x0e\x32\x1c.cline.OpenaiReasoningEffortH\x0c\x88\x01\x01\x12%\n\x18strict_plan_mode_enabled\x18\x10 \x01(\x08H\r\x88\x01\x01\x12<\n\x14\x66ocus_chain_settings\x18\x11 \x01(\x0b\x32\x19.cline.FocusChainSettingsH\x0e\x88\x01\x01\x12\x1e\n\x11use_auto_condense\x18\x12 \x01(\x08H\x0f\x88\x01\x01\x12\x1a\n\rcustom_prompt\x18\x13 \x01(\tH\x10\x88\x01\x01\x12;\n\x10\x62rowser_settings\x18\x14 \x01(\x0b\x32\x1c.cline.BrowserSettingsUpdateH\x11\x88\x01\x01\x12%\n\x18\x64\x65\x66\x61ult_terminal_profile\x18\x15 \x01(\tH\x12\x88\x01\x01\x12\x1e\n\x11yolo_mode_toggled\x18\x16 \x01(\x08H\x13\x88\x01\x01\x12\x39\n\x12\x64ictation_settings\x18\x17 \x01(\x0b\x32\x18.cline.DictationSettingsH\x14\x88\x01\x01\x12$\n\x17\x61uto_condense_threshold\x18\x18 \x01(\x01H\x15\x88\x01\x01\x12\x1f\n\x12multi_root_enabled\x18\x19 \x01(\x08H\x16\x88\x01\x01\x12\x1a\n\rhooks_enabled\x18\x1a \x01(\x08H\x17\x88\x01\x01\x12+\n\x1evscode_terminal_execution_mode\x18\x1b \x01(\tH\x18\x88\x01\x01\x12%\n\x18max_consecutive_mistakes\x18\x1c \x01(\x05H\x19\x88\x01\x01\x12\x1e\n\x11subagents_enabled\x18\x1d \x01(\x08H\x1a\x88\x01\x01\x12\x30\n#subagent_terminal_output_line_limit\x18\x1e \x01(\x05H\x1b\x88\x01\x01\x12\x16\n\tcline_env\x18\x1f \x01(\tH\x1c\x88\x01\x01\x12%\n\x18native_tool_call_enabled\x18  \x01(\x08H\x1d\x88\x01\x01\x42\x14\n\x12_api_configurationB\x14\n\x12_telemetry_settingB#\n!_plan_act_separate_models_settingB\x1d\n\x1b_enable_checkpoints_settingB\x1a\n\x18_mcp_marketplace_enabledB\x1c\n\x1a_shell_integration_timeoutB\x19\n\x17_terminal_reuse_enabledB\x1a\n\x18_mcp_responses_collapsedB\x13\n\x11_mcp_display_modeB\x1d\n\x1b_terminal_output_line_limitB\x07\n\x05_modeB\x15\n\x13_preferred_languageB\x1a\n\x18_openai_reasoning_effortB\x1b\n\x19_strict_plan_mode_enabledB\x17\n\x15_focus_chain_settingsB\x14\n\x12_use_auto_condenseB\x10\n\x0e_custom_promptB\x13\n\x11_browser_settingsB\x1b\n\x19_default_terminal_profileB\x14\n\x12_yolo_mode_toggledB\x15\n\x13_dictation_settingsB\x1a\n\x18_auto_condense_thresholdB\x15\n\x13_multi_root_enabledB\x10\n\x0e_hooks_enabledB!\n\x1f_vscode_terminal_execution_modeB\x1b\n\x19_max_consecutive_mistakesB\x14\n\x12_subagents_enabledB&\n$_subagent_terminal_output_line_limitB\x0c\n\n_cline_envB\x1b\n\x19_native_tool_call_enabled\"P\n&UpdateTerminalConnectionTimeoutRequest\x12\x17\n\ntimeout_ms\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\r\n\x0b_timeout_ms\"D\n\x12\x46ocusChainSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1d\n\x15remind_cline_interval\x18\x02 \x01(\x05\"Q\n\'UpdateTerminalConnectionTimeoutResponse\x12\x17\n\ntimeout_ms\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\r\n\x0b_timeout_ms\"i\n\x0bProcessInfo\x12\x12\n\nprocess_id\x18\x01 \x01(\x05\x12\x14\n\x07version\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tuptime_ms\x18\x03 \x01(\x03H\x01\x88\x01\x01\x42\n\n\x08_versionB\x0c\n\n_uptime_ms* \n\x0bPlanActMode\x12\x08\n\x04PLAN\x10\x00\x12\x07\n\x03\x41\x43T\x10\x01*C\n\x15OpenaiReasoningEffort\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\x0b\n\x07MINIMAL\x10\x03*3\n\x0eMcpDisplayMode\x12\x08\n\x04RICH\x10\x00\x12\t\n\x05PLAIN\x10\x01\x12\x0c\n\x08MARKDOWN\x10\x02*<\n\x14TelemetrySettingEnum\x12\t\n\x05UNSET\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x32\xd4\n\n\x0cStateService\x12\x33\n\x0egetLatestState\x12\x13.cline.EmptyRequest\x1a\x0c.cline.State\x12\x80\x01\n\x1fupdateTerminalConnectionTimeout\x12-.cline.UpdateTerminalConnectionTimeoutRequest\x1a..cline.UpdateTerminalConnectionTimeoutResponse\x12\x41\n\x1aupdateTerminalReuseEnabled\x12\x15.cline.BooleanRequest\x1a\x0c.cline.Empty\x12L\n\x1cgetAvailableTerminalProfiles\x12\x13.cline.EmptyRequest\x1a\x17.cline.TerminalProfiles\x12\x37\n\x10subscribeToState\x12\x13.cline.EmptyRequest\x1a\x0c.cline.State0\x01\x12\x39\n\x13toggleFavoriteModel\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x34\n\nresetState\x12\x18.cline.ResetStateRequest\x1a\x0c.cline.Empty\x12I\n\x16togglePlanActModeProto\x12\x1f.cline.TogglePlanActModeRequest\x1a\x0e.cline.Boolean\x12N\n\x1aupdateAutoApprovalSettings\x12\".cline.AutoApprovalSettingsRequest\x1a\x0c.cline.Empty\x12<\n\x0eupdateSettings\x12\x1c.cline.UpdateSettingsRequest\x1a\x0c.cline.Empty\x12\x42\n\x11updateSettingsCli\x12\x1f.cline.UpdateSettingsRequestCli\x1a\x0c.cline.Empty\x12\x44\n\x12updateTaskSettings\x12 .cline.UpdateTaskSettingsRequest\x1a\x0c.cline.Empty\x12\x46\n\x16updateTelemetrySetting\x12\x1e.cline.TelemetrySettingRequest\x1a\x0c.cline.Empty\x12>\n\x17setWelcomeViewCompleted\x12\x15.cline.BooleanRequest\x1a\x0c.cline.Empty\x12<\n\x17updateInfoBannerVersion\x12\x13.cline.Int64Request\x1a\x0c.cline.Empty\x12=\n\x18updateModelBannerVersion\x12\x13.cline.Int64Request\x1a\x0c.cline.Empty\x12;\n\x16updateCliBannerVersion\x12\x13.cline.Int64Request\x1a\x0c.cline.Empty\x12\x34\n\x0finstallClineCli\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12;\n\x14\x63heckCliInstallation\x12\x13.cline.EmptyRequest\x1a\x0e.cline.Boolean\x12\x39\n\x0egetProcessInfo\x12\x13.cline.EmptyRequest\x1a\x12.cline.ProcessInfoB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_PLANACTMODE']._serialized_start=16664
  _globals['_PLANACTMODE']._serialized_end=16696
  _globals['_OPENAIREASONINGEFFORT']._serialized_start=16698
  _globals['_OPENAIREASONINGEFFORT']._serialized_end=16765
  _globals['_MCPDISPLAYMODE']._serialized_start=16767
  _globals['_MCPDISPLAYMODE']._serialized_end=16818
  _globals['_TELEMETRYSETTINGENUM']._serialized_start=16820
  _globals['_TELEMETRYSETTINGENUM']._serialized_end=16880
  _globals['_AUTOAPPROVALACTIONS']._serialized_start=90
  _globals['_AUTOAPPROVALACTIONS']._serialized_end=513
  _globals['_AUTOAPPROVALSETTINGS']._serialized_start=516
  _globals['_AUTOAPPROVALSETTINGS']._serialized_end=660
  _globals['_SECRETS']._serialized_start=663
  _globals['_SECRETS']._serialized_end=2580
  _globals['_SETTINGS']._serialized_start=2583
  _globals['_SETTINGS']._serialized_end=12507
  _globals['_DICTATIONSETTINGS']._serialized_start=12509
  _globals['_DICTATIONSETTINGS']._serialized_end=12608
  _globals['_STATE']._serialized_start=12610
  _globals['_STATE']._serialized_end=12637
  _globals['_TERMINALPROFILES']._serialized_start=12639
  _globals['_TERMINALPROFILES']._serialized_end=12699
  _globals['_TERMINALPROFILE']._serialized_start=12701
  _globals['_TERMINALPROFILE']._serialized_end=12814
  _globals['_TERMINALPROFILEUPDATERESPONSE']._serialized_start=12816
  _globals['_TERMINALPROFILEUPDATERESPONSE']._serialized_end=12927
  _globals['_TOGGLEPLANACTMODEREQUEST']._serialized_start=12930
  _globals['_TOGGLEPLANACTMODEREQUEST']._serialized_end=13089
  _globals['_CHATCONTENT']._serialized_start=13091
  _globals['_CHATCONTENT']._serialized_end=13169
  _globals['_RESETSTATEREQUEST']._serialized_start=13171
  _globals['_RESETSTATEREQUEST']._serialized_end=13257
  _globals['_AUTOAPPROVALSETTINGSREQUEST']._serialized_start=13260
  _globals['_AUTOAPPROVALSETTINGSREQUEST']._serialized_end=13416
  _globals['_TELEMETRYSETTINGREQUEST']._serialized_start=13418
  _globals['_TELEMETRYSETTINGREQUEST']._serialized_end=13524
  _globals['_BROWSERSETTINGSUPDATE']._serialized_start=13527
  _globals['_BROWSERSETTINGSUPDATE']._serialized_end=13883
  _globals['_UPDATESETTINGSREQUESTCLI']._serialized_start=13886
  _globals['_UPDATESETTINGSREQUESTCLI']._serialized_end=14092
  _globals['_UPDATETASKSETTINGSREQUEST']._serialized_start=14095
  _globals['_UPDATETASKSETTINGSREQUEST']._serialized_end=14244
  _globals['_UPDATESETTINGSREQUEST']._serialized_start=14247
  _globals['_UPDATESETTINGSREQUEST']._serialized_end=16320
  _globals['_UPDATETERMINALCONNECTIONTIMEOUTREQUEST']._serialized_start=16322
  _globals['_UPDATETERMINALCONNECTIONTIMEOUTREQUEST']._serialized_end=16402
  _globals['_FOCUSCHAINSETTINGS']._serialized_start=16404
  _globals['_FOCUSCHAINSETTINGS']._serialized_end=16472
  _globals['_UPDATETERMINALCONNECTIONTIMEOUTRESPONSE']._serialized_start=16474
  _globals['_UPDATETERMINALCONNECTIONTIMEOUTRESPONSE']._serialized_end=16555
  _globals['_PROCESSINFO']._serialized_start=16557
  _globals['_PROCESSINFO']._serialized_end=16662
  _globals['_STATESERVICE']._serialized_start=16883
  _globals['_STATESERVICE']._serialized_end=18247
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.host import workspace_pb2 as host_dot_workspace__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in host/workspace_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class WorkspaceServiceStub(object):
    """Provides methods for working with workspaces/projects.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getWorkspacePaths = channel.unary_unary(
                '/host.WorkspaceService/getWorkspacePaths',
                request_serializer=host_dot_workspace__pb2.GetWorkspacePathsRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.GetWorkspacePathsResponse.FromString,
                _registered_method=True)
        self.saveOpenDocumentIfDirty = channel.unary_unary(
                '/host.WorkspaceService/saveOpenDocumentIfDirty',
                request_serializer=host_dot_workspace__pb2.SaveOpenDocumentIfDirtyRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.SaveOpenDocumentIfDirtyResponse.FromString,
                _registered_method=True)
        self.getDiagnostics = channel.unary_unary(
                '/host.WorkspaceService/getDiagnostics',
                request_serializer=host_dot_workspace__pb2.GetDiagnosticsRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.GetDiagnosticsResponse.FromString,
                _registered_method=True)
        self.openProblemsPanel = channel.unary_unary(
                '/host.WorkspaceService/openProblemsPanel',
                request_serializer=host_dot_workspace__pb2.OpenProblemsPanelRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.OpenProblemsPanelResponse.FromString,
                _registered_method=True)
        self.openInFileExplorerPanel = channel.unary_unary(
                '/host.WorkspaceService/openInFileExplorerPanel',
                request_serializer=host_dot_workspace__pb2.OpenInFileExplorerPanelRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.OpenInFileExplorerPanelResponse.FromString,
                _registered_method=True)
        self.openClineSidebarPanel = channel.unary_unary(
                '/host.WorkspaceService/openClineSidebarPanel',
                request_serializer=host_dot_workspace__pb2.OpenClineSidebarPanelRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.OpenClineSidebarPanelResponse.FromString,
                _registered_method=True)
        self.openTerminalPanel = channel.unary_unary(
                '/host.WorkspaceService/openTerminalPanel',
                request_serializer=host_dot_workspace__pb2.OpenTerminalRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.OpenTerminalResponse.FromString,
                _registered_method=True)
        self.executeCommandInTerminal = channel.unary_unary(
                '/host.WorkspaceService/executeCommandInTerminal',
                request_serializer=host_dot_workspace__pb2.ExecuteCommandInTerminalRequest.SerializeToString,
                response_deserializer=host_dot_workspace__pb2.ExecuteCommandInTerminalResponse.FromString,
                _registered_method=True)


class WorkspaceServiceServicer(object):
    """Provides methods for working with workspaces/projects.
    """

    def getWorkspacePaths(self, request, context):
        """Returns a list of the top level directories of the workspace.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def saveOpenDocumentIfDirty(self, request, context):
        """Saves an open document if it's open in the editor and has unsaved changes.
        Returns true if the document was saved, returns false if the document was not found, or did not
        need to be saved.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDiagnostics(self, request, context):
        """Get diagnostics from the workspace.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openProblemsPanel(self, request, context):
        """Makes the problems panel/pane visible in the IDE and focuses it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openInFileExplorerPanel(self, request, context):
        """Opens the IDE file explorer panel and selects a file or directory.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openClineSidebarPanel(self, request, context):
        """Opens and focuses the Cline sidebar panel in the host IDE.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openTerminalPanel(self, request, context):
        """Opens and focuses the terminal panel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def executeCommandInTerminal(self, request, context):
        """Executes a command in a new terminal
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkspaceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getWorkspacePaths': grpc.unary_unary_rpc_method_handler(
                    servicer.getWorkspacePaths,
                    request_deserializer=host_dot_workspace__pb2.GetWorkspacePathsRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.GetWorkspacePathsResponse.SerializeToString,
            ),
            'saveOpenDocumentIfDirty': grpc.unary_unary_rpc_method_handler(
                    servicer.saveOpenDocumentIfDirty,
                    request_deserializer=host_dot_workspace__pb2.SaveOpenDocumentIfDirtyRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.SaveOpenDocumentIfDirtyResponse.SerializeToString,
            ),
            'getDiagnostics': grpc.unary_unary_rpc_method_handler(
                    servicer.getDiagnostics,
                    request_deserializer=host_dot_workspace__pb2.GetDiagnosticsRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.GetDiagnosticsResponse.SerializeToString,
            ),
            'openProblemsPanel': grpc.unary_unary_rpc_method_handler(
                    servicer.openProblemsPanel,
                    request_deserializer=host_dot_workspace__pb2.OpenProblemsPanelRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.OpenProblemsPanelResponse.SerializeToString,
            ),
            'openInFileExplorerPanel': grpc.unary_unary_rpc_method_handler(
                    servicer.openInFileExplorerPanel,
                    request_deserializer=host_dot_workspace__pb2.OpenInFileExplorerPanelRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.OpenInFileExplorerPanelResponse.SerializeToString,
            ),
            'openClineSidebarPanel': grpc.unary_unary_rpc_method_handler(
                    servicer.openClineSidebarPanel,
                    request_deserializer=host_dot_workspace__pb2.OpenClineSidebarPanelRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.OpenClineSidebarPanelResponse.SerializeToString,
            ),
            'openTerminalPanel': grpc.unary_unary_rpc_method_handler(
                    servicer.openTerminalPanel,
                    request_deserializer=host_dot_workspace__pb2.OpenTerminalRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.OpenTerminalResponse.SerializeToString,
            ),
            'executeCommandInTerminal': grpc.unary_unary_rpc_method_handler(
                    servicer.executeCommandInTerminal,
                    request_deserializer=host_dot_workspace__pb2.ExecuteCommandInTerminalRequest.FromString,
                    response_serializer=host_dot_workspace__pb2.ExecuteCommandInTerminalResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.WorkspaceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('host.WorkspaceService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class WorkspaceService(object):
    """Provides methods for working with workspaces/projects.
    """

    @staticmethod
    def getWorkspacePaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/getWorkspacePaths',
            host_dot_workspace__pb2.GetWorkspacePathsRequest.SerializeToString,
            host_dot_workspace__pb2.GetWorkspacePathsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def saveOpenDocumentIfDirty(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/saveOpenDocumentIfDirty',
            host_dot_workspace__pb2.SaveOpenDocumentIfDirtyRequest.SerializeToString,
            host_dot_workspace__pb2.SaveOpenDocumentIfDirtyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getDiagnostics(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/getDiagnostics',
            host_dot_workspace__pb2.GetDiagnosticsRequest.SerializeToString,
            host_dot_workspace__pb2.GetDiagnosticsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openProblemsPanel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/openProblemsPanel',
            host_dot_workspace__pb2.OpenProblemsPanelRequest.SerializeToString,
            host_dot_workspace__pb2.OpenProblemsPanelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openInFileExplorerPanel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/openInFileExplorerPanel',
            host_dot_workspace__pb2.OpenInFileExplorerPanelRequest.SerializeToString,
            host_dot_workspace__pb2.OpenInFileExplorerPanelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openClineSidebarPanel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/openClineSidebarPanel',
            host_dot_workspace__pb2.OpenClineSidebarPanelRequest.SerializeToString,
            host_dot_workspace__pb2.OpenClineSidebarPanelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openTerminalPanel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/openTerminalPanel',
            host_dot_workspace__pb2.OpenTerminalRequest.SerializeToString,
            host_dot_workspace__pb2.OpenTerminalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def executeCommandInTerminal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.WorkspaceService/executeCommandInTerminal',
            host_dot_workspace__pb2.ExecuteCommandInTerminalRequest.SerializeToString,
            host_dot_workspace__pb2.ExecuteCommandInTerminalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/commands.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63line/commands.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"\xb0\x01\n\x0e\x43ommandContext\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rselected_text\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08language\x18\x03 \x01(\tH\x02\x88\x01\x01\x12&\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x11.cline.DiagnosticB\x0c\n\n_file_pathB\x10\n\x0e_selected_textB\x0b\n\t_language2\xeb\x01\n\x0f\x43ommandsService\x12\x31\n\naddToCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x33\n\x0c\x66ixWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x37\n\x10\x65xplainWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x37\n\x10improveWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_COMMANDCONTEXT']._serialized_start=52
  _globals['_COMMANDCONTEXT']._serialized_end=228
  _globals['_COMMANDSSERVICE']._serialized_start=231
  _globals['_COMMANDSSERVICE']._serialized_end=466
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import mcp_pb2 as cline_dot_mcp__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/mcp_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class McpServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.toggleMcpServer = channel.unary_unary(
                '/cline.McpService/toggleMcpServer',
                request_serializer=cline_dot_mcp__pb2.ToggleMcpServerRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.updateMcpTimeout = channel.unary_unary(
                '/cline.McpService/updateMcpTimeout',
                request_serializer=cline_dot_mcp__pb2.UpdateMcpTimeoutRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.addRemoteMcpServer = channel.unary_unary(
                '/cline.McpService/addRemoteMcpServer',
                request_serializer=cline_dot_mcp__pb2.AddRemoteMcpServerRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.downloadMcp = channel.unary_unary(
                '/cline.McpService/downloadMcp',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpDownloadResponse.FromString,
                _registered_method=True)
        self.restartMcpServer = channel.unary_unary(
                '/cline.McpService/restartMcpServer',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.deleteMcpServer = channel.unary_unary(
                '/cline.McpService/deleteMcpServer',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.toggleToolAutoApprove = channel.unary_unary(
                '/cline.McpService/toggleToolAutoApprove',
                request_serializer=cline_dot_mcp__pb2.ToggleToolAutoApproveRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.refreshMcpMarketplace = channel.unary_unary(
                '/cline.McpService/refreshMcpMarketplace',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpMarketplaceCatalog.FromString,
                _registered_method=True)
        self.openMcpSettings = channel.unary_unary(
                '/cline.McpService/openMcpSettings',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.subscribeToMcpMarketplaceCatalog = channel.unary_stream(
                '/cline.McpService/subscribeToMcpMarketplaceCatalog',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpMarketplaceCatalog.FromString,
                _registered_method=True)
        self.getLatestMcpServers = channel.unary_unary(
                '/cline.McpService/getLatestMcpServers',
                request_serializer=cline_dot_common__pb2.Empty.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)
        self.subscribeToMcpServers = channel.unary_stream(
                '/cline.McpService/subscribeToMcpServers',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_mcp__pb2.McpServers.FromString,
                _registered_method=True)


class McpServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def toggleMcpServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateMcpTimeout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def addRemoteMcpServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def downloadMcp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def restartMcpServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteMcpServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleToolAutoApprove(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def refreshMcpMarketplace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openMcpSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToMcpMarketplaceCatalog(self, request, context):
        """Subscribe to MCP marketplace catalog updates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getLatestMcpServers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToMcpServers(self, request, context):
        """Subscribe to MCP server updates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_McpServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'toggleMcpServer': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleMcpServer,
                    request_deserializer=cline_dot_mcp__pb2.ToggleMcpServerRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'updateMcpTimeout': grpc.unary_unary_rpc_method_handler(
                    servicer.updateMcpTimeout,
                    request_deserializer=cline_dot_mcp__pb2.UpdateMcpTimeoutRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'addRemoteMcpServer': grpc.unary_unary_rpc_method_handler(
                    servicer.addRemoteMcpServer,
                    request_deserializer=cline_dot_mcp__pb2.AddRemoteMcpServerRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'downloadMcp': grpc.unary_unary_rpc_method_handler(
                    servicer.downloadMcp,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpDownloadResponse.SerializeToString,
            ),
            'restartMcpServer': grpc.unary_unary_rpc_method_handler(
                    servicer.restartMcpServer,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'deleteMcpServer': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteMcpServer,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'toggleToolAutoApprove': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleToolAutoApprove,
                    request_deserializer=cline_dot_mcp__pb2.ToggleToolAutoApproveRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'refreshMcpMarketplace': grpc.unary_unary_rpc_method_handler(
                    servicer.refreshMcpMarketplace,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpMarketplaceCatalog.SerializeToString,
            ),
            'openMcpSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.openMcpSettings,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'subscribeToMcpMarketplaceCatalog': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToMcpMarketplaceCatalog,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpMarketplaceCatalog.SerializeToString,
            ),
            'getLatestMcpServers': grpc.unary_unary_rpc_method_handler(
                    servicer.getLatestMcpServers,
                    request_deserializer=cline_dot_common__pb2.Empty.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
            'subscribeToMcpServers': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToMcpServers,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_mcp__pb2.McpServers.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.McpService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.McpService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class McpService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def toggleMcpServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/toggleMcpServer',
            cline_dot_mcp__pb2.ToggleMcpServerRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateMcpTimeout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/updateMcpTimeout',
            cline_dot_mcp__pb2.UpdateMcpTimeoutRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def addRemoteMcpServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/addRemoteMcpServer',
            cline_dot_mcp__pb2.AddRemoteMcpServerRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def downloadMcp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/downloadMcp',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_mcp__pb2.McpDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def restartMcpServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/restartMcpServer',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def deleteMcpServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/deleteMcpServer',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleToolAutoApprove(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/toggleToolAutoApprove',
            cline_dot_mcp__pb2.ToggleToolAutoApproveRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def refreshMcpMarketplace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/refreshMcpMarketplace',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_mcp__pb2.McpMarketplaceCatalog.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openMcpSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/openMcpSettings',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToMcpMarketplaceCatalog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.McpService/subscribeToMcpMarketplaceCatalog',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_mcp__pb2.McpMarketplaceCatalog.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getLatestMcpServers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.McpService/getLatestMcpServers',
            cline_dot_common__pb2.Empty.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToMcpServers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.McpService/subscribeToMcpServers',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_mcp__pb2.McpServers.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.host import diff_pb2 as host_dot_diff__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in host/diff_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DiffServiceStub(object):
    """Provides methods for diff views.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.openDiff = channel.unary_unary(
                '/host.DiffService/openDiff',
                request_serializer=host_dot_diff__pb2.OpenDiffRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.OpenDiffResponse.FromString,
                _registered_method=True)
        self.getDocumentText = channel.unary_unary(
                '/host.DiffService/getDocumentText',
                request_serializer=host_dot_diff__pb2.GetDocumentTextRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.GetDocumentTextResponse.FromString,
                _registered_method=True)
        self.replaceText = channel.unary_unary(
                '/host.DiffService/replaceText',
                request_serializer=host_dot_diff__pb2.ReplaceTextRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.ReplaceTextResponse.FromString,
                _registered_method=True)
        self.scrollDiff = channel.unary_unary(
                '/host.DiffService/scrollDiff',
                request_serializer=host_dot_diff__pb2.ScrollDiffRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.ScrollDiffResponse.FromString,
                _registered_method=True)
        self.truncateDocument = channel.unary_unary(
                '/host.DiffService/truncateDocument',
                request_serializer=host_dot_diff__pb2.TruncateDocumentRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.TruncateDocumentResponse.FromString,
                _registered_method=True)
        self.saveDocument = channel.unary_unary(
                '/host.DiffService/saveDocument',
                request_serializer=host_dot_diff__pb2.SaveDocumentRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.SaveDocumentResponse.FromString,
                _registered_method=True)
        self.closeAllDiffs = channel.unary_unary(
                '/host.DiffService/closeAllDiffs',
                request_serializer=host_dot_diff__pb2.CloseAllDiffsRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.CloseAllDiffsResponse.FromString,
                _registered_method=True)
        self.openMultiFileDiff = channel.unary_unary(
                '/host.DiffService/openMultiFileDiff',
                request_serializer=host_dot_diff__pb2.OpenMultiFileDiffRequest.SerializeToString,
                response_deserializer=host_dot_diff__pb2.OpenMultiFileDiffResponse.FromString,
                _registered_method=True)


class DiffServiceServicer(object):
    """Provides methods for diff views.
    """

    def openDiff(self, request, context):
        """Open the diff view/editor.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDocumentText(self, request, context):
        """Get the contents of the diff view.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def replaceText(self, request, context):
        """Replace a text selection in the diff.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def scrollDiff(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def truncateDocument(self, request, context):
        """Truncate the diff document.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def saveDocument(self, request, context):
        """Save the diff document.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def closeAllDiffs(self, request, context):
        """Close all the diff editor windows/tabs.
        Any diff editors with unsaved content should not be closed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def openMultiFileDiff(self, request, context):
        """Display a diff view comparing before/after states for multiple files.
        Content is passed as in-memory data, not read from the file system.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiffServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'openDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.openDiff,
                    request_deserializer=host_dot_diff__pb2.OpenDiffRequest.FromString,
                    response_serializer=host_dot_diff__pb2.OpenDiffResponse.SerializeToString,
            ),
            'getDocumentText': grpc.unary_unary_rpc_method_handler(
                    servicer.getDocumentText,
                    request_deserializer=host_dot_diff__pb2.GetDocumentTextRequest.FromString,
                    response_serializer=host_dot_diff__pb2.GetDocumentTextResponse.SerializeToString,
            ),
            'replaceText': grpc.unary_unary_rpc_method_handler(
                    servicer.replaceText,
                    request_deserializer=host_dot_diff__pb2.ReplaceTextRequest.FromString,
                    response_serializer=host_dot_diff__pb2.ReplaceTextResponse.SerializeToString,
            ),
            'scrollDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.scrollDiff,
                    request_deserializer=host_dot_diff__pb2.ScrollDiffRequest.FromString,
                    response_serializer=host_dot_diff__pb2.ScrollDiffResponse.SerializeToString,
            ),
            'truncateDocument': grpc.unary_unary_rpc_method_handler(
                    servicer.truncateDocument,
                    request_deserializer=host_dot_diff__pb2.TruncateDocumentRequest.FromString,
                    response_serializer=host_dot_diff__pb2.TruncateDocumentResponse.SerializeToString,
            ),
            'saveDocument': grpc.unary_unary_rpc_method_handler(
                    servicer.saveDocument,
                    request_deserializer=host_dot_diff__pb2.SaveDocumentRequest.FromString,
                    response_serializer=host_dot_diff__pb2.SaveDocumentResponse.SerializeToString,
            ),
            'closeAllDiffs': grpc.unary_unary_rpc_method_handler(
                    servicer.closeAllDiffs,
                    request_deserializer=host_dot_diff__pb2.CloseAllDiffsRequest.FromString,
                    response_serializer=host_dot_diff__pb2.CloseAllDiffsResponse.SerializeToString,
            ),
            'openMultiFileDiff': grpc.unary_unary_rpc_method_handler(
                    servicer.openMultiFileDiff,
                    request_deserializer=host_dot_diff__pb2.OpenMultiFileDiffRequest.FromString,
                    response_serializer=host_dot_diff__pb2.OpenMultiFileDiffResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'host.DiffService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('host.DiffService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DiffService(object):
    """Provides methods for diff views.
    """

    @staticmethod
    def openDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/openDiff',
            host_dot_diff__pb2.OpenDiffRequest.SerializeToString,
            host_dot_diff__pb2.OpenDiffResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getDocumentText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/getDocumentText',
            host_dot_diff__pb2.GetDocumentTextRequest.SerializeToString,
            host_dot_diff__pb2.GetDocumentTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def replaceText(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/replaceText',
            host_dot_diff__pb2.ReplaceTextRequest.SerializeToString,
            host_dot_diff__pb2.ReplaceTextResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def scrollDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/scrollDiff',
            host_dot_diff__pb2.ScrollDiffRequest.SerializeToString,
            host_dot_diff__pb2.ScrollDiffResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def truncateDocument(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/truncateDocument',
            host_dot_diff__pb2.TruncateDocumentRequest.SerializeToString,
            host_dot_diff__pb2.TruncateDocumentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def saveDocument(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/saveDocument',
            host_dot_diff__pb2.SaveDocumentRequest.SerializeToString,
            host_dot_diff__pb2.SaveDocumentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def closeAllDiffs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/closeAllDiffs',
            host_dot_diff__pb2.CloseAllDiffsRequest.SerializeToString,
            host_dot_diff__pb2.CloseAllDiffsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def openMultiFileDiff(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/host.DiffService/openMultiFileDiff',
            host_dot_diff__pb2.OpenMultiFileDiffRequest.SerializeToString,
            host_dot_diff__pb2.OpenMultiFileDiffResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/testing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/testing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12host/testing.proto\x12\x04host\"\x17\n\x15GetWebviewHtmlRequest\"4\n\x16GetWebviewHtmlResponse\x12\x11\n\x04html\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_html2]\n\x0eTestingService\x12K\n\x0egetWebviewHtml\x12\x1b.host.GetWebviewHtmlRequest\x1a\x1c.host.GetWebviewHtmlResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.testing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_GETWEBVIEWHTMLREQUEST']._serialized_start=28
  _globals['_GETWEBVIEWHTMLREQUEST']._serialized_end=51
  _globals['_GETWEBVIEWHTMLRESPONSE']._serialized_start=53
  _globals['_GETWEBVIEWHTMLRESPONSE']._serialized_end=105
  _globals['_TESTINGSERVICE']._serialized_start=107
  _globals['_TESTINGSERVICE']._serialized_end=200
# @@protoc_insertion_point(module_scope)
